==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/es.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividades",
    "An error occurred while loading activities" : "Ocurrió un error al cargar las actividades",
    "No activity yet" : "Ninguna actividad aún",
    "Load more activities" : "Cargar más actividades",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos agregados, modificados y compartidos",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente es inválida",
    "Your settings have been updated." : "Tus ajustes han sido actualizados.",
    "Settings have been updated." : "La configuración ha sido actualizada.",
    "Mail" : "Correo electrónico",
    "Stream" : "Flujo",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por ti",
    "\"remote user\"" : "\"usuario remoto\"",
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Ha habido actividad en %s",
    "_and %n more _::_and %n more _" : ["y 1%n más","y %n más "],
    "Activity notification" : "Notificación de actividad",
    ", " : ", ",
    "%s and %s" : "%s y %s",
    "Activity" : "Actividad",
    "Activity feed" : "Fuente de actividad",
    "Configure the default activity settings for new users." : "Escoger la configuración de actividad por defecto para nuevos usuarios",
    "List your own actions in the stream" : "Enumerar tus propias acciones en el flujo",
    "Notify about your own actions via email" : "Notificarse sobre tus propias acciones por correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Debes configurar tu dirección de correo electrónico antes de poder recibir notificaciones.",
    "Send emails:" : "Enviar correos:",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escoger para qué actividades se quiere recibir una notificación por correo y cuál debería aparecer en el flujo de la app de Actividad.",
    "Settings" : "Configuración",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "No more events to load" : "No hay más eventos por cargar.",
    "Files" : "Archivos",
    "Error loading activities" : "Error al cargar las actividades",
    "No activities" : "No hay actividades",
    "You are receiving this email because the following things happened at %s" : "Recibes este correo porque esto ha sucedido en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* %n más","* y %n más"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/es.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividades",
    "An error occurred while loading activities" : "Ocurrió un error al cargar las actividades",
    "No activity yet" : "Ninguna actividad aún",
    "Load more activities" : "Cargar más actividades",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Home" : "Inicio",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos agregados, modificados y compartidos",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Open file" : "Abrir archivo",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente es inválida",
    "Your settings have been updated." : "Tus ajustes han sido actualizados.",
    "Settings have been updated." : "La configuración ha sido actualizada.",
    "Mail" : "Correo electrónico",
    "Stream" : "Flujo",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por ti",
    "\"remote user\"" : "\"usuario remoto\"",
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Ha habido actividad en %s",
    "_and %n more _::_and %n more _" : ["y 1%n más","y %n más "],
    "Activity notification" : "Notificación de actividad",
    ", " : ", ",
    "%s and %s" : "%s y %s",
    "Activity" : "Actividad",
    "Activity feed" : "Fuente de actividad",
    "Send activity emails" : "Enviar correos de actividad",
    "Default settings" : "Configuraciones por defecto",
    "Configure the default activity settings for new users." : "Escoger la configuración de actividad por defecto para nuevos usuarios",
    "List your own actions in the stream" : "Enumerar tus propias acciones en el flujo",
    "Notify about your own actions via email" : "Notificarse sobre tus propias acciones por correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Debes configurar tu dirección de correo electrónico antes de poder recibir notificaciones.",
    "Send emails:" : "Enviar correos:",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escoger para qué actividades se quiere recibir una notificación por correo y cuál debería aparecer en el flujo de la app de Actividad.",
    "Choose which activities you want to see in your stream." : "Escoge qué actividades quieres ver en tu lista.",
    "Settings" : "Configuración",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "No more events to load" : "No hay más eventos por cargar.",
    "Files" : "Archivos",
    "Error loading activities" : "Error al cargar las actividades",
    "No activities" : "No hay actividades",
    "You are receiving this email because the following things happened at %s" : "Recibes este correo porque esto ha sucedido en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* %n más","* y %n más"]
},
"nplurals=2; plural=(n != 1);");
